@@ -2,22 +2,25 @@ package LaTeX::Pod;
 
 use strict;
 use warnings;
+use boolean qw(true false);
 
 use Carp qw(croak);
 use LaTeX::TOM;
 
-our $VERSION = '0.10_01';
+our $VERSION = '0.18_01';
 
-sub new {
-    my ($self, $file) = @_;
+sub new
+{
+    my $class = shift;
 
-    my $class = ref($self) || $self;
-    croak "$file: $!" unless -f $file;
+    my $self = bless {}, ref($class) || $class;
+    $self->_init(@_);
 
-    return bless _init_self({ file => $file }), $class;
+    return $self;
 }
 
-sub convert {
+sub convert
+{
     my $self = shift;
 
     my $nodes = $self->_init_tom;
@@ -26,7 +29,7 @@ sub convert {
         $self->{current_node} = $node;
         my $type = $node->getNodeType;
 
-        if ($type =~ /TEXT|COMMENT/) {
+        if ($type =~ /^(?:TEXT|COMMENT)$/) {
             next if $node->getNodeText !~ /\w+/
                  or $node->getNodeText =~ /^\\\w+$/m
                  or $self->_process_directives;
@@ -38,9 +41,11 @@ sub convert {
                     $dispatched++;
                }
             }
-        } elsif ($type =~ /ENVIRONMENT/) {
+        }
+        elsif ($type eq 'ENVIRONMENT') {
             $self->_process_verbatim;
-        } elsif ($type =~ /COMMAND/) {
+        }
+        elsif ($type eq 'COMMAND') {
             $self->_unregister_previous('verbatim');
             my $cmd_name = $node->getCommandName;
 
@@ -55,15 +60,16 @@ sub convert {
     return $self->_pod_finalize;
 }
 
-sub _init_self {
-    my $args = shift;
+sub _init
+{
+    my ($self, $file) = @_;
 
-    my %opts;
+    croak "$file: $!" unless -f $file;
 
-    $opts{file}      = $args->{file};
-    $opts{title_inc} = 1;
+    $self->{file}      = $file;
+    $self->{title_inc} = 1;
 
-    @{$opts{dispatch_text}} = (
+    @{$self->{dispatch_text}} = (
         [ q{$self->_is_set_node('title')},    q{$self->_process_text_title}     ],
         [ q{$self->_is_set_node('verbatim')}, q{$self->_process_text_verbatim}  ],
         [ q{$node->getNodeText =~ /\\\item/}, q{$self->_process_text_item}      ],
@@ -73,7 +79,7 @@ sub _init_self {
         [ q{!$dispatched},                    q{$self->_process_text}           ],
     );
 
-    @{$opts{dispatch_command}} = (
+    @{$self->{dispatch_command}} = (
         [ q{$self->_is_set_previous('item')},                   q{$self->_process_item}               ],
         [ q{$cmd_name eq 'chapter'},                            q{$self->_process_chapter}            ],
         [ q{$cmd_name eq 'section'},                            q{$self->_process_section}            ],
@@ -83,11 +89,10 @@ sub _init_self {
         [ q{$cmd_name eq 'author'},                             q{$self->_register_node('docauthor')} ],
         [ q{$cmd_name =~ /textbf|textsf|emph/},                 q{$self->_register_node($cmd_name)}   ],
     );
-
-    return \%opts;
 }
 
-sub _init_tom {
+sub _init_tom
+{
     my $self = shift;
 
     # silently discard warnings about unparseable latex
@@ -98,14 +103,15 @@ sub _init_tom {
     return $nodes;
 }
 
-sub _process_directives {
+sub _process_directives
+{
     my $self = shift;
 
     foreach my $node qw(directive docauthor) {
         if ($self->_is_set_node($node)) {
             $self->_unregister_node($node);
 
-            return 1;
+            return true;
         }
     }
 
@@ -115,13 +121,14 @@ sub _process_directives {
         $self->_pod_add('=head1 '.$self->{current_node}->getNodeText);
         $self->{title_inc}++;
 
-        return 1;
+        return true;
     }
 
-    return 0;
+    return false;
 }
 
-sub _process_text_title {
+sub _process_text_title
+{
     my $self = shift;
 
     if ($self->_is_set_previous('item')) {
@@ -138,7 +145,8 @@ sub _process_text_title {
     $self->_register_previous('title');
 }
 
-sub _process_text_verbatim {
+sub _process_text_verbatim
+{
     my $self = shift;
 
     my $text = $self->{current_node}->getNodeText;
@@ -154,10 +162,12 @@ sub _process_text_verbatim {
 
         if ($len) {
             $text = ' ' x $len . $text;
-        } else {
+        }
+        else {
             $text =~ s/^(.*)$/\ $1/gm;
         }
-    } else {
+    }
+    else {
         $self->_pod_scrub_newlines(\$text);
     }
 
@@ -171,7 +181,8 @@ sub _process_text_verbatim {
     $self->_register_previous('verbatim');
 }
 
-sub _process_text_item {
+sub _process_text_item
+{
     my $self = shift;
 
     unless ($self->_is_set_previous('item')) {
@@ -182,7 +193,8 @@ sub _process_text_item {
 
     if ($text =~ /\\item\s*\[(.*?)\]/) {
         $self->_pod_add("=item $1");
-    } else {
+    }
+    else {
         $self->_pod_add('=item');
     }
 
@@ -192,7 +204,8 @@ sub _process_text_item {
     $self->_register_previous('item');
 }
 
-sub _process_text {
+sub _process_text
+{
     my $self = shift;
 
     my $text = $self->{current_node}->getNodeText;
@@ -205,7 +218,8 @@ sub _process_text {
     $self->_register_previous('text');
 }
 
-sub _process_verbatim {
+sub _process_verbatim
+{
     my $self = shift;
 
     $self->_unregister_previous('verbatim');
@@ -215,7 +229,8 @@ sub _process_verbatim {
     }
 }
 
-sub _process_item {
+sub _process_item
+{
     my $self = shift;
 
     unless ($self->{current_node}->getCommandName eq 'mbox') {
@@ -227,7 +242,8 @@ sub _process_item {
     }
 }
 
-sub _process_chapter {
+sub _process_chapter
+{
     my $self = shift;
 
     $self->{title_inc}++;
@@ -236,14 +252,16 @@ sub _process_chapter {
     $self->_register_node('title');
 }
 
-sub _process_section {
+sub _process_section
+{
     my $self = shift;
 
     $self->_pod_add('=head'.$self->{title_inc}.' ');
     $self->_register_node('title');
 }
 
-sub _process_subsection {
+sub _process_subsection
+{
     my $self = shift;
 
     my $sub_often;
@@ -257,7 +275,8 @@ sub _process_subsection {
     $self->_register_node('title');
 }
 
-sub _process_spec_chars {
+sub _process_spec_chars
+{
     my ($self, $text) = @_;
 
     my %umlauts = (a => '',
@@ -278,7 +297,8 @@ sub _process_spec_chars {
     $$text =~ s/\\newline//g;
 }
 
-sub _process_tags {
+sub _process_tags
+{
     my ($self, $tag) = @_;
 
     my $text = $self->{current_node}->getNodeText;
@@ -287,96 +307,109 @@ sub _process_tags {
                 textsf => 'C',
                 emph   => 'I');
 
-    $self->{append_following} = 1;
+    $self->{append_following} = true;
 
     $self->_pod_append("$tags{$tag}<$text>");
     $self->_unregister_node($tag);
 }
 
-sub _pod_add {
+sub _pod_add
+{
     my ($self, $content) = @_;
 
     if (!$self->{append_following}) {
         push @{$self->{pod}}, $content;
-    } else {
+    }
+    else {
         $self->_pod_append($content);
-        $self->{append_following} = 0;
+        $self->{append_following} = false;
     }
 }
 
-sub _pod_append {
+sub _pod_append
+{
     my ($self, $content) = @_;
 
     $self->{pod}->[-1] .= $content;
 }
 
-sub _pod_scrub_newlines {
+sub _pod_scrub_newlines
+{
     my ($self, $text) = @_;
 
     $$text =~ s/^\n*//;
     $$text =~ s/\n*$//;
 }
 
-sub _pod_scrub_whitespaces {
+sub _pod_scrub_whitespaces
+{
     my ($self, $text) = @_;
 
     $$text =~ s/^\s*//;
     $$text =~ s/\s*$//;
 }
 
-sub _pod_get {
+sub _pod_get
+{
     my $self = shift;
 
     return $self->{pod};
 }
 
-sub _pod_finalize {
+sub _pod_finalize
+{
     my $self = shift;
 
-    $self->_pod_add('=cut');
+    $self->_pod_add("=cut\n");
 
     return join "\n\n", @{$self->_pod_get};
 }
 
-sub _register_node {
+sub _register_node
+{
     my ($self, $item) = @_;
 
-    $self->{node}{$item} = 1;
+    $self->{node}{$item} = true;
 }
 
-sub _is_set_node {
+sub _is_set_node
+{
     my ($self, $item) = @_;
 
-    return $self->{node}{$item} ? 1 : 0;
+    return $self->{node}{$item} ? true : false;
 }
 
-sub _unregister_node {
+sub _unregister_node
+{
     my ($self, $item) = @_;
 
     delete $self->{node}{$item};
 }
 
-sub _register_previous {
+sub _register_previous
+{
     my ($self, $item) = @_;
 
-    $self->{previous}{$item} = 1;
+    $self->{previous}{$item} = true;
 }
 
-sub _is_set_previous {
+sub _is_set_previous
+{
     my ($self, $item) = @_;
 
     my @items = ref($item) eq 'ARRAY' ? @$item : ($item);
 
     foreach my $item_single (@items) {
         if ($self->{previous}{$item_single}) {
-            return 1;
+            return true;
         }
     }
 
-    return 0;
+    return false;
 }
 
-sub _unregister_previous {
+sub _unregister_previous
+{
     my ($self, $item) = @_;
 
     my @items = ref($item) eq 'ARRAY' ? @$item : ($item);
@@ -396,7 +429,7 @@ LaTeX::Pod - Transform LaTeX source files to POD (Plain old documentation)
 
  use LaTeX::Pod;
 
- my $parser = LaTeX::Pod->new('/path/to/latex/source');
+ my $parser = LaTeX::Pod->new('/path/to/latex-source');
  print $parser->convert;
 
 =head1 DESCRIPTION
@@ -411,7 +444,7 @@ see below for detailed information.
 
 The constructor requires that the path to the latex source must be declared:
 
- $parser = LaTeX::Pod->new('/path/to/latex/source');
+ $parser = LaTeX::Pod->new('/path/to/latex-source');
 
 Returns the parser object.
 
@@ -451,20 +484,22 @@ It's not much, but there's more to come:
 
 The current implementation is a bit I<flaky> because C<LaTeX::TOM>, the framework
 being used for parsing the LaTeX nodes, makes a clear distinction between various
-types of nodes. As example, an \item directive has quite often a separate text which
-is associated with former one. And they can't be detected without some kind of
-sophisticated "lookbehind", which is what is done.
+types of nodes. As example, an \item directive has quite often a separate text
+associated with it as its content. Such directives and their expected converted
+relatives within the output stream possibly cannot be easily detected without
+some kind of sophisticated "look-behind" mechanism, which is how C<LaTeX::Pod>
+internally functions.
 
-The author tried to implement a I<context-sensitive> awareness for C<LaTeX::Pod>. He 
-did so by setting which node has been seen before the current one in order to be able 
-to call the appropriate routine for a LaTeX directive with two or more nodes.
-Furthermore, C<LaTeX::Pod> registers which node it has previously encountered
-and unregisters this information when it made use of it.
+C<LaTeX::Pod> was designed with the intention to be I<context-sensitive> aware.
+This is being achieved by setting which node has been seen before the current one in
+order to be able to call the appropriate routine for a LaTeX directive with two or
+more nodes. Furthermore, C<LaTeX::Pod> registers which node it has previously
+encountered and unregisters this information when it made use of it.
 
-Considering that the POD language has a limited subset of commands, the overhead
-of keeping track of node occurences seems almost bearable. The POD processed
-may consist of too many newlines before undergoing the scrubbing where leading and
-trailing newlines will be truncated.
+Considering that the POD documentation format has a limited subset of directives,
+the overhead of keeping track of node occurences appears to be bearable. The POD
+computed may consist of too many newlines before undergoing a transformation
+where leading and trailing newlines will be truncated.
 
 =head1 SEE ALSO
 
